<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class IntegracaoHcmFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }

    public function getParamsGeral(){
        $sql = "SELECT DSURLHCM, DSIDHCM, DSSECRETHCM, DSTOKENHCM 
                  FROM PARAMGERAL";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }


    public function getParametrosContrato($params){

        $sql = "SELECT NRSEQCONTRATO, NRCONTRATOFCT, 
                       NVL(IDINTEGRACAOHCM, 'N') AS IDINTEGRACAOHCM, 
                       NVL(TPESTRUTINTEGRAHCM, 'T') AS TPESTRUTINTEGRAHCM, 
                       NVL(IDINTEGRAESCALAHCM, 'N') AS IDINTEGRAESCALAHCM
                  FROM FCT_CONTRATO
                 WHERE FCT_CONTRATO.NRSEQCONTRATO = :NRSEQCONTRATO";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getDadosContratoTomador($params) {
        
        $sql = "SELECT DISTINCT FCT_CONTRATO.NRSEQCONTRATO, TO_CHAR(NVL(FCT_CONTRATO.DTINIVIGENCONT, FCT_CONTRATO.DTINICIOCONTRATO), 'MM/DD/YYYY') AS DTINICIOCONTRATO, TO_CHAR(NVL(FCT_CONTRATO.DTFINVIGENCONT, FCT_CONTRATO.DTFIMCONTRATO), 'DD/MM/YYYY') AS DTFIMCONTRATO, 
                                FCT_CONTRATO.NRPARCNEGOCIO,  PARCNEGOCIO.NRINSCRICAOPARC,
                                ENDERECOPARC.CDTIPOENDERECO,  NVL(ENDERECOPARC.DSENDERECO, 'Não há') AS DSENDERECO, MUNICIPIO.NMMUNICIPIO, NMPRINCIPALPARC,  ENDERECOPARC.NMBAIRROENDERECO, 
                                ENDERECOPARC.SGESTADO, NVL(ENDERECOPARC.DSCOMPLEENDERECO, 'Não há') AS DSCOMPLEENDERECO, ENDERECOPARC.NRCEPENDERECO, NVL(ENDERECOPARC.NRIMOVELENDERECO, 0) AS NRIMOVELENDERECO, ENDERECOPARC.CDPAIS, 
                                NVL(ENDERECOPARC.CDLOGRADOURO,0) AS CDLOGRADOURO, NVL(ENDERECOPARC.DSREFERENCIAENDE, 'Não há') DSREFERENCIAENDE, PAIS.NMPAIS
                        FROM FCT_CONTRATO
                        LEFT JOIN ENDERECOPARC
                        ON FCT_CONTRATO.NRPARCNEGOCIO = ENDERECOPARC.NRPARCNEGOCIO
                        LEFT JOIN PARCNEGOCIO
                        ON FCT_CONTRATO.NRPARCNEGOCIO = PARCNEGOCIO.NRPARCNEGOCIO
                        LEFT JOIN MUNICIPIO
                        ON ENDERECOPARC.CDMUNICIPIO = MUNICIPIO.CDMUNICIPIO
                        AND ENDERECOPARC.SGESTADO = MUNICIPIO.SGESTADO
                        AND ENDERECOPARC.CDPAIS = MUNICIPIO.CDPAIS
                        LEFT JOIN PAIS
                        ON ENDERECOPARC.CDPAIS = PAIS.CDPAIS
                        WHERE FCT_CONTRATO.NRSEQCONTRATO = :NRSEQCONTRATO
                        AND CDTIPOENDERECO = 'PRINCIPAL'";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getDadosContratoPosto($params) {
        
        $sql = "SELECT CONT.NRSEQCONTRATO,  ESTRM.NRESTRUTURAM,  ESTRM.CDFILIAL, ESTRM.CDCENTCUST,
                       TO_CHAR(NVL(CONT.DTINIVIGENCONT, CONT.DTINICIOCONTRATO), 'MM/DD/YYYY') AS DTINICIOCONTRATO, 
                       TO_CHAR(NVL(CONT.DTFINVIGENCONT, CONT.DTFIMCONTRATO), 'DD/MM/YYYY') AS DTFIMCONTRATO, 
                       ESTRM.NRPARCNEGOCIO,  PARC.NRINSCRICAOPARC, ENDPARC.CDTIPOENDERECO, NVL(ENDPARC.DSENDERECO, 'Não há') AS DSENDERECO, MUNICIPIO.NMMUNICIPIO, 
                       PARC.NMPRINCIPALPARC,  ENDPARC.NMBAIRROENDERECO, ENDPARC.SGESTADO, NVL(ENDPARC.DSCOMPLEENDERECO, 'Não há') AS DSCOMPLEENDERECO, ENDPARC.NRCEPENDERECO, 
                       NVL(ENDPARC.NRIMOVELENDERECO, 0) AS NRIMOVELENDERECO, ENDPARC.CDPAIS, NVL(ENDPARC.CDLOGRADOURO,0) AS CDLOGRADOURO, 
                       NVL(ENDPARC.DSREFERENCIAENDE, 'Não há') DSREFERENCIAENDE, PAIS.NMPAIS 
                  FROM FCT_RELACESTRUTURACONT  RELEST 
                  JOIN FCT_CONTRATO CONT
                    ON CONT.NRSEQCONTRATO = RELEST.NRSEQCONTRATO
                  JOIN ESTRUTURAM ESTRM
                    ON ESTRM.NRESTRUTURAM = RELEST.NRESTRUTURAM
                  JOIN PARCNEGOCIO PARC
                    ON PARC.NRPARCNEGOCIO = ESTRM.NRPARCNEGOCIO
                  JOIN ENDERECOPARC ENDPARC
                    ON ENDPARC.NRPARCNEGOCIO = ESTRM.NRPARCNEGOCIO
                  JOIN MUNICIPIO
                    ON ENDPARC.CDMUNICIPIO = MUNICIPIO.CDMUNICIPIO
                   AND ENDPARC.SGESTADO = MUNICIPIO.SGESTADO
                   AND ENDPARC.CDPAIS = MUNICIPIO.CDPAIS
                  JOIN PAIS
                    ON ENDPARC.CDPAIS = PAIS.CDPAIS
                 WHERE CONT.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND ENDPARC.CDTIPOENDERECO = 'PRINCIPAL'";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function validaContratoPosto($params) {
        
      $sql = "SELECT ITCONT.NRITEMOCONTRATO, NVL(ITCONT.NMCONTRATUALITEMCONT, ITCONT.NMITEMCONTRATO) AS NMITEMCONTRATO, 
                    ITCONT.NRESTRUTURAM, DECODE(ITCONT.NRESTRUTURAM, NULL, 'S','N') ERRO1,
                    ESTRM.NMESTRUTURAM, ESTRM.CDFILIAL, DECODE(ITCONT.NRESTRUTURAM, NULL, 'N',DECODE(ESTRM.CDFILIAL, NULL, 'S', 'N')) ERRO2,
                    ESTRM.CDCENTCUST, DECODE(ITCONT.NRESTRUTURAM, NULL, 'N',DECODE(ESTRM.CDCENTCUST, NULL, 'S', 'N')) ERRO3
                FROM FCT_ITEMCONTRATO ITCONT
              LEFT JOIN ESTRUTURAM ESTRM
                ON ESTRM.NRESTRUTURAM = ITCONT.NRESTRUTURAM
              AND ESTRM.NRORG = ITCONT.NRORG 
              WHERE ITCONT.NRSEQCONTRATO = :NRSEQCONTRATO";

      $std = $this->connection->prepare($sql);
      $std->execute($params);
      return $std->fetchAll();
  }

    public function verificarUtilizaIntegracao(array $params) {
        $sql = "SELECT IDINTEGRACAOHCM
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]['IDINTEGRACAOHCM'];
    }

    public function updateToken($params) {
        $sql = "UPDATE PARAMGERAL
                   SET DSTOKENHCM = :TOKEN";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getItensContrato($params) {
        $sql = "SELECT NRSEQCONTRATO, NRITEMOCONTRATO, CDSERVORCA, QTITEMCONTRATO, NRESTRUTURAM, NRESCALATRABALHOHCM
                            FROM FCT_ITEMCONTRATO  
                          WHERE NRSEQCONTRATO  = :NRSEQCONTRATO
                            AND ((:TIPOESTRUT = 'T') OR ((:TIPOESTRUT = 'P') AND (NRESTRUTURAM = :NRESTRUTURAM)))";
          
          $std = $this->connection->prepare($sql);
          $std->execute($params);
          return $std->fetchAll();
    }

    public function deleteEscalasHCMTemp($params) {
        $sql = "DELETE FROM FCT_ESCALATRABHCM_TMP 
                 WHERE NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function insertEscalasHCMTemp($params) {
        $sql = "INSERT INTO FCT_ESCALATRABHCM_TMP (NRESCALATRABM, NMESCALATRABH, NRNMESCALATRABM, NRORG, DTINCLUSAO, CDOPERINCLUSAO)
                       VALUES (:NRESCALATRABM, :NMESCALATRABH, :NRNMESCALATRABM, :NRORG, SYSDATE, :CDOPERINCLUSAO)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

}